package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````0"%```````!``````````,C(````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$````````S"````````#,(`````````
M`"````````$````&````$,(````````0PF```````!#"8```````=`0`````
M``"("0``````````(````````@````8````XP@```````#C"8```````.,)@
M```````0`@```````!`"````````"``````````$````!````!@"````````
M&`)````````8`D```````#``````````,``````````$`````````%#E=&0$
M````Z+T```````#HO4```````.B]0```````Q`````````#$``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`&-"#P`(````!`````(```!&<F5E0E-$``````!A
M````90```````````````````"0`````````7````%L````3````````````
M```S`````````#4````Q`````````$T````G````4@```$H```!>````8```
M`%<````B````)0``````````````#P```%8````5````-@`````````:````
M/````#(````'`````````$(````>````%P```#\`````````*`````````!C
M````3@```$$````[``````````````!9````#@```#T````4````1P````8`
M``!B````*@```"P````Y`````````"T````I`````````%``````````````
M````````````-P```!@```!$````,````!L```!(````````````````````
M7P```%0````#````/@```#H````K`````````$P```!+````````````````
M````50`````````X````40`````````N````+P````````````````````$`
M````````````````````````````````````````````````````````````
M````````````#0``````````````#`````4````(```````````````*````
M0````%@```!=``````````````````````````L`````````````````````
M````````````````````$0````D`````````'0```!\``````````````!D`
M``!&`````````"``````````$@`````````````````````````"````10``
M`&$```!D````0P```$\````$````````````````````````````````````
M````````````````4P``````````````````````````````(P```#0`````
M`````````````````````````$D```!:````````````````````)@``````
M````````%@``````````````$``````````<````(0```"4```!`````!```
M``@```!@#,"`!40$@2H:`"B`AH&H@BD!8$T`!'B(@#!)N@`&"$````!!````
M0P```$8```!'````2````$H``````````````$P```````````````````!-
M````3@````````!/``````````````!0````40```%,``````````````%0`
M``!6````6````%D```!<````70```%\``````````````&$```!B````8P``
M``````"]4':>SMY'+:/@^TF^HH54!A9&(%MWRZ8?^-$-20NMA:;=HVLA8F0'
M+L6;MA>J5W>)GFS\35U$U(D'<-,A_^0."XH05[(!BV]K?YI\?ZF<FV[%WQ_9
M<5@<NN.2?.<5`X/59-1\,F+;[>"G`@J-(L49B_U'Q6:OS&9[\$IKXD?&`4-%
MU>Q]08[%P^4_+/+;TQW[H6Q@````````````````````````````````W`$`
M`!(``````````````!T/````````Z````!(``````````````!@`````````
M(00``!(``````````````!,`````````Q0$``!(``````````````"8<````
M````C0(``!(``````````````!$`````````0P(``!(``````````````/H`
M````````#````"``````````````````````````.`$``!(`````````````
M```$````````=0```!(``````````````-8`````````*`$``!(`````````
M`````#,`````````#P$``!(``````````````!4!````````60,``!(`````
M`````````"D`````````#P,``!(``````````````)@`````````)P,``!(`
M`````````````%(`````````:`,``!(``````````````!$`````````8`,`
M`!(``````````````%,`````````;0(``!(``````````````!$`````````
MXP$``!(``````````````",`````````G0(``!(```````````````8`````
M````00$``!(``````````````&@#````````E@(``!(``````````````$D`
M````````M@(``!(``````````````,P`````````0`,``!(`````````````
M`(0`````````.`(``!(``````````````#T`````````*````!(`````````
M`````!@`````````@`(``!(``````````````$P`````````A@(``!(`````
M`````````.,`````````/@(``!(``````````````%(`````````UP```!(`
M`````````````.H`````````9@```!(``````````````.X(````````90(`
M`!(``````````````"0`````````;`(``!(``````````````!$`````````
MIP(``!(``````````````!$`````````Q@(``!(``````````````!$`````
M`````@,``!(``````````````!$`````````W`(``!(``````````````#$`
M````````HP```!(``````````````#`!````````>`$``!(`````````````
M`%,"````````:@$``!(``````````````#D6````````4@,``!(`````````
M`````!$`````````ZP(``!(``````````````$D`````````%@,``!(`````
M`````````!``````````\@```!(``````````````"0!````````K@(``!(`
M`````````````/<0````````2`(``!(``````````````$,`````````^@(`
M`!(``````````````$L`````````<@(``!(``````````````$H`````````
M>0(``!(``````````````&<`````````"`,``!(``````````````!$`````
M````S`(``!(``````````````%0`````````T`$``!(``````````````#(`
M````````OP```!(``````````````-8`````````6P,``!(`````````````
M`#0`````````N@$``!(``````````````((`````````[0```!(`````````
M`````/T`````````3P$``!(``````````````)0"````````0````!(`````
M`````````$T`````````O@(``!(``````````````$H`````````TP(``!(`
M`````````````'D`````````\P(``!(``````````````'X`````````Y`(`
M`!(``````````````#8`````````3P```!(``````````````.D`````````
MD0```!(```````````````0)````````6@(``!$`%P!8QF````````@`````
M````6@0``!(`#0!`,$```````"T,````````D`0``!(`#0#`*4```````$`#
M````````S````!$`&`"@QF````````$`````````@P```!$`&`"PQF``````
M``$`````````_@```!$`&`#HQF````````@`````````"0$``!$`&`#(QF``
M``````@`````````'0$``!$`&`#8QF````````$`````````(````!$`&`"0
MRV````````@`````````+@,``!$`&`#PQF```````$``````````JP,``!(`
M#0!@)$````````H`````````DP$``!$`&`"0QF````````$`````````-@``
M`!$`&`#`QF````````@`````````6@$``!$`&`#@QF````````@`````````
MA@0``!$`%P!XQF````````@`````````>00``!(`#0!P)$```````!H"````
M````L@```!$`&``PQV````````$`````````WP,``!(`#0#@+4```````+H`
M````````G00``!(`#0#00T```````!D#````````#P0``!(`#0"@+D``````
M`!X`````````*@0``!(`#0!P/$```````&D`````````=@,``!``\?^$QF``
M````````````````@@,``!``\?^8RV``````````````````2`,``!$`&`!@
MQV````````@`````````R0,``!(`#0`@/T```````*,$````````>P,``!(`
M#0!`(4```````%8!````````[0,``!(`#0"0(T```````,,`````````_0$`
M`!$`&`!HQV````````@`````````A@$``!$`&`#0QF````````@`````````
M`P0``!(`#0#P*$```````,D`````````J@$``!(```#L'D```````(L!````
M````O`,``!(`#0#`*$```````"D`````````;P,``!``\?^$QF``````````
M````````/@0``!(`#0`P/D```````!L`````````-@0``!(`#0!P(T``````
M`!D`````````[@$``!$`&`!`QV```````!,`````````9P0``!(`#0#`+D``
M`````'0!`````````&QI8G!E<FPN<V\`7TIV7U)E9VES=&5R0VQA<W-E<P!E
M;G9I<F]N`%!E<FQ?<WES7W1E<FT`4$Q?8V]M<&-V`%!E<FQ?<WES7VEN:70S
M`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`<&5R;%]C;VYS=')U8W0`4&5R;%]A
M=E]S:&EF=`!03%]E>&ET7V9L86=S`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6<'8`4$Q?:6Y?979A
M;`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!03%]T
M;W!?96YV`%!,7V]P`%!E<FQ?<W9?<V5T<'8`4$Q?=&%I;G1E9`!097)L7V=V
M7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`%!,
M7V-U<G-T86-K:6YF;P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`4$Q?
M979A;%]R;V]T`%!,7W!E<FQ?9&5S=')U8W1?;&5V96P`8F]O=%]$>6YA3&]A
M9&5R`%!E<FQ?8W)O86L`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!03%]P87)S97(`;&EB;2YS;RXU
M`&QI8F-R>7!T+G-O+C4`;&EB=71I;"YS;RXY`&QI8G1H<BYS;RXS`&-L;W-E
M`')E860`;W!E;@!?7V5R<F]R`&QI8F,N<V\N-P!?7W!R;V=N86UE`&UE;6-H
M<@!L<W1A=`!M96UC<'D`<W1R<W1R`&QS965K`'-T<FQE;@!R96%D;&EN:P!S
M=')D=7``7VEN:71?=&QS`&=E='5I9`!R96%L;&]C`&9P<FEN=&8`;65M;6]V
M90!M:V1I<@!M96US970`8VQO<V5D:7(`<W1R;F-M<`!S=')C:'(`<W1R;F-P
M>0!S=')C;7``;W!E;F1I<@!R;61I<@!G971P:60`<W1R=&]K`%]?<W1A8VM?
M8VAK7V9A:6P`97AE8W9P`%]?<W1A8VM?8VAK7V=U87)D`'-P<FEN=&8`7U]S
M=&1E<G)P`&%C8V5S<P!A=&5X:70`<F5A9&1I<@!U;FQI;FL`7V5D871A`%]?
M8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XQ-"]M86-H
M+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`'AS7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+
M`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`
M;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!M86EN`$9"4T1?,2XP``````(````"
M`````@`#```````````````"``(``@`"``(``@````(````"``(``@`#````
M`@`"``,```````(``@`"``(``@`"``````````(``@`"`````@`#``(``@`"
M``(``@```````@````(```````(``@`"``(```````$``0`!````````````
M```!``(``0`````````!``$````!``$``0`!``$``0`"``$``0`!```````!
M`````0`!``$``0````$````!``$`+`(``!`````@````L"AZ!P```P"B!```
M``````$``0!0`@``$`````````"P*'H'```"`*($````````D,9@```````%
M````2P``````````````H,9@```````%````0P``````````````L,9@````
M```%````1```````````````P,9@```````%````3```````````````R,9@
M```````%````1@``````````````T,9@```````%````7```````````````
MV,9@```````%````1P``````````````X,9@```````%````30``````````
M````Z,9@```````%````10``````````````\,9@```````%````20``````
M````````,,=@```````%````4```````````````0,=@```````%````8P``
M````````````8,=@```````%````5P``````````````:,=@```````%````
M6P``````````````8,1@```````'`````0``````````````:,1@```````'
M`````@``````````````<,1@```````'`````P``````````````>,1@````
M```'````!```````````````@,1@```````'````!0``````````````B,1@
M```````'````!@``````````````D,1@```````'````"```````````````
MF,1@```````'````"0``````````````H,1@```````'````"@``````````
M````J,1@```````'````"P``````````````L,1@```````'````#```````
M````````N,1@```````'````#0``````````````P,1@```````'````#@``
M````````````R,1@```````'````#P``````````````T,1@```````'````
M$```````````````V,1@```````'````$0``````````````X,1@```````'
M````$@``````````````Z,1@```````'````$P``````````````\,1@````
M```'````%```````````````^,1@```````'````%0```````````````,5@
M```````'````%@``````````````",5@```````'````%P``````````````
M$,5@```````'````&```````````````&,5@```````'````&0``````````
M````(,5@```````'````&@``````````````*,5@```````'````&P``````
M````````,,5@```````'````7@``````````````.,5@```````'````'```
M````````````0,5@```````'````'0``````````````2,5@```````'````
M'@``````````````4,5@```````'````'P``````````````6,5@```````'
M````(```````````````8,5@```````'````(0``````````````:,5@````
M```'````(@``````````````<,5@```````'````(P``````````````>,5@
M```````'````)```````````````@,5@```````'````)0``````````````
MB,5@```````'````)@``````````````D,5@```````'````)P``````````
M````F,5@```````'````*```````````````H,5@```````'````*0``````
M````````J,5@```````'````*@``````````````L,5@```````'````*P``
M````````````N,5@```````'````+```````````````P,5@```````'````
M+0``````````````R,5@```````'````+@``````````````T,5@```````'
M````+P``````````````V,5@```````'````,```````````````X,5@````
M```'````,0``````````````Z,5@```````'````,@``````````````\,5@
M```````'````,P``````````````^,5@```````'````-```````````````
M`,9@```````'````-0``````````````",9@```````'````-@``````````
M````$,9@```````'````-P``````````````&,9@```````'````.```````
M````````(,9@```````'````.0``````````````*,9@```````'````.@``
M````````````,,9@```````'````.P``````````````.,9@```````'````
M/```````````````0,9@```````'````/0``````````````2,9@```````'
M````/@``````````````4,9@```````'````/P``````````````2(/L".@/
M!@``Z!I!``!(@\0(PP#_-0ZG(`#_)1"G(``/'T``_R4.IR``:`````#IX/__
M__\E!J<@`&@!````Z=#_____)?ZF(`!H`@```.G`_____R7VIB``:`,```#I
ML/____\E[J8@`&@$````Z:#_____)>:F(`!H!0```.F0_____R7>IB``:`8`
M``#I@/____\EUJ8@`&@'````Z7#_____)<ZF(`!H"````.E@_____R7&IB``
M:`D```#I4/____\EOJ8@`&@*````Z4#_____);:F(`!H"P```.DP_____R6N
MIB``:`P```#I(/____\EIJ8@`&@-````Z1#_____)9ZF(`!H#@```.D`____
M_R66IB``:`\```#I\/[___\ECJ8@`&@0````Z>#^____)8:F(`!H$0```.G0
M_O___R5^IB``:!(```#IP/[___\E=J8@`&@3````Z;#^____)6ZF(`!H%```
M`.F@_O___R5FIB``:!4```#ID/[___\E7J8@`&@6````Z8#^____)5:F(`!H
M%P```.EP_O___R5.IB``:!@```#I8/[___\E1J8@`&@9````Z5#^____)3ZF
M(`!H&@```.E`_O___R4VIB``:!L```#I,/[___\E+J8@`&@<````Z2#^____
M)2:F(`!H'0```.D0_O___R4>IB``:!X```#I`/[___\E%J8@`&@?````Z?#]
M____)0ZF(`!H(````.G@_?___R4&IB``:"$```#IT/W___\E_J4@`&@B````
MZ<#]____)?:E(`!H(P```.FP_?___R7NI2``:"0```#IH/W___\EYJ4@`&@E
M````Z9#]____)=ZE(`!H)@```.F`_?___R76I2``:"<```#I</W___\ESJ4@
M`&@H````Z6#]____)<:E(`!H*0```.E0_?___R6^I2``:"H```#I0/W___\E
MMJ4@`&@K````Z3#]____):ZE(`!H+````.D@_?___R6FI2``:"T```#I$/W_
M__\EGJ4@`&@N````Z0#]____)9:E(`!H+P```.GP_/___R6.I2``:#````#I
MX/S___\EAJ4@`&@Q````Z=#\____)7ZE(`!H,@```.G`_/___R5VI2``:#,`
M``#IL/S___\E;J4@`&@T````Z:#\____)6:E(`!H-0```.F0_/___R5>I2``
M:#8```#I@/S___\E5J4@`&@W````Z7#\____)4ZE(`!H.````.E@_/___R5&
MI2``:#D```#I4/S___\E/J4@`&@Z````Z4#\____)3:E(`!H.P```.DP_/__
M_R4NI2``:#P```#I(/S___\E)J4@`&@]````Z1#\____)1ZE(`!H/@```.D`
M_/__`````%5(B>5!5T%6055!5%-028G\38LT)$ECQDV-?,002(,]*ZH@``!U
M!TR)/2*J(`!)@\0(187V?C1)BP0D2(7`="OK$69F9F9F+@\?A```````2/_`
M2(D%OJ0@`.L$2/_`D(H(@/DO=.F$R77QN#C"8`!(A<!T"DB)]^@O_/__ZP7H
MF/S__[@XPF``2(7`#X6O````OZ`B0`#H$/S__[D,PF``N`S"8`!(*<A)B<5)
MP?T_2<'M/4D!Q4G!_0--A>UT,3';9F9F9F8N#Q^$``````!(BP3=#,)@`$B#
M^`)R"T2)]TR)YDR)^O_02/_#3#GK<M^Y#,)@`+@,PF``2"G(28G%2<']/TG!
M[3U)`<5)P?T#Z-/Z__]-A>UT)S';#Q]``$B+!-T,PF``2(/X`G(+1(GW3(GF
M3(GZ_]!(_\-,.>MRWT2)]TR)YDR)^NA!(0``B<?H]OW__V8N#Q^$``````!5
M2(GE4U"Y#,)@`+@,PF``2"G(2(G#2,'[/TC!ZSU(`<-(P?L#ZPMF#Q^$````
M``#_T$B%VW032(L$W03"8`!(_\M(@_@!=NKKYDB#Q`A;7>F3.P``D)"0D)"0
MD)"0D)!52(GEB@5FHR``A,!T#^LC2(/!"$B)#4VC(`#_T$B+#42C(`!(BP%(
MA<!UY,8%/:,@``%=PV9F+@\?A```````54B)Y4B#/>2>(```=!*X`````$B%
MP'0(OS#"8`!=_^!=PY"0D)"0D)"0D)"0D)"054B)Y;_47D``ONP>0`"ZR%Y`
M`%WI,_W__P\?@`````!52(GE05=!5E-(@>PH"```2(L%2:,@`$B)1>#HG/S_
M_TB-O=#[__^^H+I``(G"N7"]0``PP.C2^O__13'VA<!X7TB-O=#[__](C;7`
M]___N@`$``#HH_G__TB)PX7;>$!(P>,@2+\``````0```$@!WTC!_R#H0OG_
M_TF)QTV%_W0>2,'[($B-M<#W__],B?](B=KH!/S__T'&!!\`38G^2(L%N:(@
M`$@[1>!U$4R)\$B!Q"@(``!;05Y!7UW#Z(G[__]F9F9F+@\?A```````54B)
MY5WI)O___V8/'T0``%5(B>5!5T%6055!5%-(@>R(!```2(FU4/O__TF)_DB+
M!5NB(`!(B47013'D3(LM[:8@`$V%[71GN*RZ0`#K!)!(_\"*"(3)=`6`^3UU
M\DF+70!(A=MT2+FLND``*<A,8_A)@\4(9F8N#Q^$``````!(B=^^K+I``$R)
M^NB,^O__A<!U!T*`/#L]=`])BUT`28/%"$B%VW78ZP5-C60?`4R)][XO````
MZ/#[__](A<`/A1`!``!,B??HK_G__TF)QTB+O5#[__^^?KU``.B[^/__2(7`
M#X3K````0?_'2(V=T/O__V9F9BX/'X0``````$&]=KU``(`X`'0#28G%387D
M=!-,B>=,B>[H?OO__X7`#X2:````3(GOZ$[Y__^-2/](8]%!@'P5`"]U*DP!
MZHUP_DAC]DP![@\?A```````_\G&`@!(8]%,`>K_R(`^+TB-=O]TZD0!^#T`
M!```?65(B=^^Y;M``$R)ZKFVNT``38GP,,#HLOC__TB)WTB-M5C[___H0_C_
M_X7`=2,/MX5@^___)0#P``!F/0"`=1%(B=^^`0```.B@^?__A<!T1#'_OGZ]
M0`#HT/?__TB%P`^%*____[^UND``3(GVZ$X```!(BP6GH"``2#M%T'4V3(GP
M2('$B`0``%M!7$%=05Y!7UW#2(V=T/O__[^UND``2(G>Z!@```!(B=_H_/?_
M_TF)QNN]Z%+Y__]F#Q]$``!52(GE05=!5D%505132(/L&$F)]4F)_D&`?0`]
M=0-)_\5,B>_H(_C__TB)1=!,BSW,I"``387V=`5-A?]U(4F+!T4QY$B%P`^$
MBP```$4QY$N#?.<(`$V-9"0!=?/K>4R)\.L/9F9F+@\?A```````2/_`B@B$
MR70%@/D]=?))BP]%,>1(A<ET3T0I\$ACV$R)^$B)1<A)B<](B4W`28G$3(G_
M3(GV2(G:Z#[X__^%P'4+08`\'ST/A!0!``!-BWPD"$F#Q`A-A?]UU4R+?<A(
MBT7`Z6G___^`/1FD(``!=2A!C40D`DAC\$C!Y@-,B?_H=_C__TF)QTR)/0&D
M(`!-A?]U1>D7`0``Q@7HHR```4&-1"0"2&/X2,'G`^B;]?__2(G#2(7;#X3S
M````26/42,'B`TB)WTR)_N@-^?__2(D=NJ,@`$F)WT&-1"0!2&/`2<<$QP``
M``!,B??K!6:02/_'B@>$P'0$/#UU\[@"````1"GP2(M-T`'!`<_H.O7__T2)
MX4F)!,](A<`/A(X```!(BP5GHR``2(L$R.L'D$C_P$G_QD&*#H@(A,ET!8#Y
M/77LQ@`]N0$````/'T``08I4#?^(%`A(_\&$TG7QZT],`?M(_\-,BWW(2(M%
MP`^$7/[__TTI_$G![`-(B=_H6/;__TB+3=")R4@YR`^"5O___V9F9F8N#Q^$
M``````!!BD4`B`-(_\-)_\6$P'7P2(/$&%M!7$%=05Y!7UW#D%5(B>7K"DB)
MQP\?@`````!(B?A(_\"*2/^$R70'@/DO=?'KXDB)^%W##Q^``````%5(B>5!
M5E-(B?M(A=L/A*$```!$BC-%A/8/A)4```!(B=_HQ?7__TB-3`/_2/_(2(7`
M?A]F9F8N#Q^$``````"`.2]U#DC_R4@YV78&Z_&02/_)2#G9=@6`.2]U\T@Y
MV71,2/_)9F8N#Q^$``````!(B<I(*=IV"8`Y+TB-2?]T[TB-0@)%,?9(/0`$
M``!W%DC_PD&^<,=@`+]PQV``2(G>Z#;V__],B?!;05Y=PT&`_B]U#K]VO4``
M6T%>7>G*]/__O[:[0`#K\`\?@`````!52(GE05=!5D%505132(/L2$B+!1B=
M(`!(B470#R@%K9,```\I1;`/*`62DP``#RE%H&;'1<```+_"ND``Z/X"``"_
MR[I``.CT`@``O].Z0`#HZ@(``+_<ND``Z.`"``"_X[I``.C6`@``O_.Z0`#H
MS`(``+^LND``Z,("``"__[I``.BX`@``OPF[0`#HK@(``+\3NT``Z*0"``"_
MM;I``.B:`@``OQV[0`#HD`(``+\FNT``Z(8"``!,BR4/H2``387D#X0A`@``
MN#&[0`#K$F9F9F9F9BX/'X0``````$C_P(H(A,ET!8#Y/77R38L\)$V%_W1>
MN3&[0``IR$QC\$F-7"0(9BX/'X0``````$R)_[XQNT``3(GRZ)ST__^%P'4'
M0X`\-SUT#DR+.TB#PPA-A?]UV>L<30'^2?_&=!2_";M``$R)]NB"^___3(LE
M>Z`@`$V%Y`^$C0$``+A"NT``ZPYF9BX/'X0``````$C_P(H(A,ET!8#Y/77R
M38L\)$V%_W1>N4*[0``IR$QC\$F-7"0(9BX/'X0``````$R)_[Y"NT``3(GR
MZ`ST__^%P'4'0X`\-SUT#DR+.TB#PPA-A?]UV>L<30'^2?_&=!2_5+M``$R)
M]NCR^O__3(LEZY\@`$V%Y`^$_0```+A?NT``ZPYF9BX/'X0``````$C_P(H(
MA,ET!8#Y/77R38L\)$&];[M``$V%_W1-N5^[0``IR$QC\$R)99A-C60D"$R)
M^V9F9F8N#Q^$``````!(B=^^7[M``$R)\NAL\___A<!U!T*`/#,]=!5)BQPD
M28/$"$B%VW78ZQY,B668ZQA)`=Y)_\9T$+^LND``3(GVZ88```!)_\5!BD4`
MA,!(BUV8=`0\/77M387_=$ZX;[M``$$IQ4UC]4B#PP@/'T``3(G_OF^[0`!,
MB?+H_/+__X7`=0=#@#PW/70.3(L[2(/#"$V%_W79ZQ)-`?Y)_\9T"K__ND``
M3(GVZR!(C7VQOH"[0`"Z"@```.B^\O__A<!U#DB-=;N__[I``.C`^?__O^.Z
M0`"^B[M``.BQ^?__2(L%"IH@`$@[1=!U#TB#Q$A;05Q!74%>05]=P^C<\O__
M54B)Y4%7059!54%44U!)B?Y-A?8/A+8```#IH0```)!,B?#K#F9F+@\?A```
M````2/_`B@B$R70'@/D]=?)FD$V++"1-A>T/A(,```!$*?!,8_A,B>-F+@\?
MA```````3(GO3(GV3(GZZ`[R__^%P'4(0X!\/0`]=`],BVL(2(/#"$V%[779
MZT=-`>])@___=#Y,*>-(P>L#2&/#28U$Q`AF9F9F9F8N#Q^$``````!(BPA(
MB4CX2(/`"$B%R77P3(LER9T@`$V%Y`^%4/___TB#Q`A;05Q!74%>05]=PY!5
M2(GE05=!5D%44XL%CY@@`(/X_P^%EP```$&W`4R+)8R=(`!-A>1T>[C_ND``
MZP-(_\"*"(3)=`6`^3UU\DF+'"1(A=MT7;G_ND``*<A,8_!)@\0(9F8N#Q^$
M``````!(B=^^_[I``$R)\N@L\?__A<!U!T*`/#,]=`])BQPD28/$"$B%VW78
MZQI)`=Y)_\9T$D&*#H#Y,`^4P(3)00^4QT$(QT$/ML>#\`&)!>^7(`!;05Q!
M7D%?7<-F#Q]$``!52(GEZ*/P__^)Q^B\[O__2(7`=`5(BP!=PS'`7<-FD%5(
MB>5!5T%6055!5%-(@^Q(28G^#U?`#RE%P`\I1;`/*46@2,=%T`````!(QT6@
ME[M``$C'1:B-NT``2,=%L)J[0`!(QT6XD+M``$C'1<"5NT``0;^7NT``2,=%
MR*>[0`"X`0```.L+#Q^$``````!(_\!(B4683(LM4IP@`$V%[4R)^'1ZZPL/
M'X0``````$C_P(H(A,ET!X#Y/77R9I!)BUT`2(7;=%=$*?A,8^!)@\4(9F9F
M9BX/'X0``````$B)WTR)_DR)XNCN[___A<!U!T*`/",]=`])BUT`28/%"$B%
MVW7:ZQA)`=Q)_\1T$$R)Y^@D[___2(G#2(7;=1Y,B?],B?;HQ?;__TB+19A,
MBWS%H$V%_W1,Z5+___],B>=,B?;H4_#__TB%P'7=3(GWZ.;N__](C7P#`NA,
M[?__2(G#2(G?ON6[0`!,B?*Y?KU``$V)X##`Z'_N__],B?](B=[KH4B#Q$A;
M05Q!74%>05]=PV9F9BX/'X0``````%5(B>5!5T%6055!5%-(@>RX@@``28G\
M2(L%DI8@`$B)1=`/5\`/*84`?O__#RF%\'W__P\IA>!]__](QX7@??__5+M`
M`$C'A>A]__]-NT``2,>%\'W__[B[0`!(QX7X??__:KM``$C'A0!^___`NT``
M3(L]V)H@`$V%_P^$C@```+BLND``ZPL/'X0``````$C_P(H(A,ET!8#Y/77R
M28L?2(7;=&FYK+I``"G(3&/P28/'"&9F9BX/'X0``````$B)W[ZLND``3(GR
MZ&SN__^%P'4'0H`\,SUT#DF+'TF#QPA(A=MUV>LF20'>2?_&=!Y!@#X`=!A,
MB??H@?W__TR)]^@U[?__28G$Z24$``!,B:58??__Z/'M__^)Q^@*[/__13'_
M2(7`=!9(BP!(A<`/A<P```!F+@\?A```````3(LM"9H@`$V%[;@`````#X2;
M````3HLT_="]0`!,B?'K$69F9F9F+@\?A```````2/_!B@&$P'0'/#UU\P\?
M`$F+70!(A=NX`````'1B1"GQ3&/A28/%"`\?A```````2(G?3(GV3(GBZ([M
M__^%P'4'0H`\(SUT$4F+70!)@\4(2(7;==HQP.LF20'<2?_$N`````!T&4&`
M/"0`N`````!T#4R)Y^A1[/__#Q]$``!(A<!U#4G_QT&#_P(/@C[___]!O]>[
M0`!(A<!,#T7X3(G_Z(7L__](C7P``>CKZO__28G&08H'A,!T-4G_QTR)\V9F
M9F9F9BX/'X0```````^VT$B)W[[>NT``,,#H"NS__TB#PP)!B@=)_\>$P'7@
M3(FU4'W__TR+K>!]__]-A>T/A/L```!!O@$```#K!)!)_\9,BR7&F"``387D
M3(GH#X2Z````ZPL/'X0``````$C_P(H(A,ET!X#Y/77R9I!-BSPD387_#X23
M````1"GH2&/828/$"&8/'X0``````$R)_TR)[DB)VNA>[/__A<!U!T&`/!\]
M=`]-BSPD28/$"$V%_W7:ZUA,`?M(_\-T4(`[`'1+2(G?2(VU&'[__^CHZ___
MA<!U.`^WA2!^__\E`/```#T`0```=`<]`*```'4>2(G?O@(```#H/>S__X7`
M=!]F9F9F+@\?A```````3HNL]>!]__]-A>UT%>D>____2(G?Z-+J__])B<9-
MA?9U>TR-I9!^__\QV^L&#Q\`2/_#@_L!=UU,BS3=L+U``$&`/@!T5$R)]TR)
MYNA;Z___A<!UVP^WA9A^__\E`/```#T`0```=`<]`*```'7!3(GWO@(```#H
ML.O__X7`=;!,B??H9.K__TF)QDC_PTV%]G2@ZPA%,?;K`T4Q]DR)]^BGZO__
M28G'3(NM4'W__TR)[^B5ZO__18UD!P1(N```````!```2<'D($D!Q$G!_"!,
MB>?HX^C__TB)Q[[CNT``3(GR2(G#N;:[0`!!N-*[0`!-B>DPP.@0ZO__2(G?
MOL`!``#HP^K__X/X_TR+K5A]__]U#NABZ___@S@1#X63````2(VU"'___TB)
MWTB)G3A]___H<^K__X7`=59,B[40?___1(GP)0#P``!F/0!`=4%,B?-(P>L@
MZ%[J__\YPW4Q08'F_P$``&9!@?[``74B3(GGZ$/H__])B<1,BSU]EB``387_
M#X3R````N)"[0`#K>DF+50!(BSTRDB``OB>\0`!(BXTX??__,,#H2^G__T4Q
MY.LN28G?38MU`$B+'0R2(`#HL^K__T2+`$B)W[[LNT``3(GR3(GY,,#H&^G_
M_T4QY$B+!761(`!(.T70#X40!0``3(G@2('$N((``%M!7$%=05Y!7UW#2/_`
MB@B$R70%@/D]=?))BQ](A=MT7KF0NT``*<A,8_!)@\<(2(G?OI"[0`!,B?+H
MKNG__X7`=0="@#PS/70.28L?28/'"$B%VW79ZR=)`=Y)_\9T'TF+70!,B??H
M@>C__TB)WTB)QNAJ[O__28G&387V=01-BW4`3(GWZ,+H__](B<.#^P1\8TAC
MPTJ-?##\OGJ\0`#HR.K__X7`=4V#^P1T'$C!XR!(N`````#[____2`'82,'X
M($&`/`8O=2Q)BUT(2(7;="-(B=_H<NC__TB#^`1R%4B-?!C\OG^\0`#H?>K_
M_X7`3`]$\^A6]___A<`/A>8```!,B?<Q]C#`Z/[F__^)PXF=1'W__X7;#X3*
M````B=](Q\;N____N@(```#H"^C__TB-M:!___^)W[H&````Z"CH__](BX6@
M?___#[?(2('Y`$,```^%-`$``(G!P>D0@/E!#X4F`0``N0```/\CC:!___^!
M^0```$,/A0\!``!(N0````#__P``2"'(2+D`````2$4``$@YR`^%[P```(G?
M2,?&QO___[H"````Z(GG__^)WTB-G:!___](B=ZZ*0```.BCY___3(GGOH2\
M0`!,B[4X??__3(GRN;:[0`!)B=CIQ@0``+__ND``OHN[0`#H">___^C`Z/__
M3(GGOI.\0`!,B[4X??__3(GRN;:[0`!!B<!!N06]0``PP.CIYO__3(GGOL`!
M``#HG.?__X/X_P^%@@0``+L!````Z#GH__^#.!$/A6\$``#H:^C__TC'!"0%
MO4``3(GGOJ&\0`!,B?*YMKM``$&)P$&)V3#`Z);F__],B>>^P`$``.A)Y___
M_\.#^/]TM.DL!```3(FE,'W__XG?,?8QTNB;YO__2,>%8'W__P$C16>XB:O-
M[TB)A6A]__^X_MRZF$B)A7!]__](QX5X??__=E0R$+CPX=+#2(F%@'W__TR-
MM:!___\/5\#'A=A]__\`````#Q&%B'W__XG?3(GVN@"```#H9^;__TF)Q$6%
MY`^.A`$``$R-K9A]__],C;U@??__2(NUB'W__TB+A9!]__]*C0SE``````'Q
M26/42#GQ<PI(_\!(B860??__2(F-B'W__TC!ZAU(`<)(B960??__2&.%V'W_
M_TB%P'4%3(GVZTZY0````"G!1#GA00]/S$ACV4B-O`68??__3(GV2(G:Z`GG
M__^+A=A]__\!V(F%V'W__X/X0`^%R@```$R)_^CN#0``02G<2(VT':!___]!
M@_Q`#XR6````08U$),")A5!]__]!B<9!P>X&3(GP2,'@!DB)A4A]__],B?M)
MB?=(B;58??__00\0!T$/$$\000\05R!!#Q!?,$$/$5TP00\152!!#Q%-$$$/
M$44`2(G?Z'T-``!)@\=`08/$P$&#_#]_PTB+M5A]__](BX5(??__2(UT,$!!
MP>8&BX50??__1"GP3(VUH'___TF)W^L#1(G@2&/83(GO2(G:Z"[F__^)G=A]
M__^+G41]__^)WTR)]KH`@```Z./D__])B<1%A>0/CXK^__^)W^B`Y/__2(N=
MB'W__TR+M9!]__^)VL'J`X/B/XU"`<:$%9A]__^`2(V\!9A]__^#^#ER0(/R
M/S'VZ/CE__](C;U@??__Z,`,```/5\`/$86X??__#Q&%J'W__P\1A9A]__](
MQX7(??__`````.L6Z$+E__^X-P```"G02&/0,?;HL>7__TR+I3!]__],B?%(
MB<A(P>@8B(70??__2(G(2,'H$(B%T7W__XBMTGW__XB-TWW__TB)V$C!Z!!(
MB=E(P>D82(V]8'W__XB-U'W__XB%U7W__XB]UGW__XB=UWW__^@C#```3(UU
MH+L!````2(N-8'W__TB)R$C!Z!B(A8!___](B<I(P>H0B)6!?___B*V"?___
MB(V#?___2(N-:'W__TB)RDC!ZA!(B<Y(P>X80(BUA'___XB5A7___XBMAG__
M_XB-AW___TB+C7!]__](B<I(P>H8B)6(?___2(G*2,'J$(B5B7___XBMBG__
M_XB-BW___TB+C7A]__](B<I(P>H8B)6,?___2(G*2,'J$(B5C7___XBMCG__
M_XB-CW___TB+C8!]__](B<I(P>H8B)60?___2(G*2,'J$(B5D7___XBMDG__
M_XB-DW___^L.28/&`HJ$'8!___](_\,/MM!,B?>^WKM``##`Z(+B__^#^Q1U
MV\9%R`!,C46@3(GGOH2\0`!,B[4X??__3(GRN;:[0`!!N06]0``PP.A1XO__
M3(GWZ%GD__^_K+I``$R)YN@PZO__3(GGZ%CR___I!_G__P\?`%5(B>5!5E-)
MB?[H<>S__TB)PTB-0P'K"P\?A```````2/_`BDC_A,ET!X#Y+W3@Z^_H.O'_
M_X7`="%-A?9T'$&`/@!T%DB)W[[2NT``N@0```#HM>+__X7`=`5;05Y=PTR)
M]UM!7EWK!P\?@`````!52(GE05=!5D%505132(/L>$F)_$V%Y`^$&P$``$&`
M/"0`#X00`0``3(GGZ`SC__])B<9-A?8/A/P```!,B??H".'__TB)PTB%VP^$
MV````$R-O6#___]F#Q^$``````!(@\,(2(G?OG:]0`#HJ^/__X7`#X2;````
M2(G?OG6]0`#HEN/__X7`#X2&````3(GGZ&;A__])B<5(B=_H6^'__T&-?`4!
M2,'G($BX``````$```!(`<=(P?\@Z*S?__])B<5,B>^^>+U``$R)XDB)V3#`
MZ.3@__],B>],B?[H>>#__X/X_W0<#[>%:/___R4`\```9CT`0'4*3(GOZ/[^
M___K"$R)[^@PX/__3(GOZ+CB__],B??H,.#__TB)PTB%VP^%./___TR)]^C<
MXO__3(GGZ%3A__](@\1X6T%<05U!7D%?7<-F#Q^$``````!52(GEO______H
M+N#__[]0/D``,?9=Z='B__\/'T0``%5(B>534`^V!4.((`"#X'](BPUAB"``
M#[=)(,'A!PG!2(L%:8@@`$B+0`AFB4@",=N_!;U``#'VZ._A__](BPU,B"``
M2(M)"$B)02A(BP4]B"``2(M`"$B+#2*((`!(B4@P2(L%KX@@`$B%P'0'2(N8
MJ````$B+!12((`!(BT`(2(E8.$B+!06((`!(BT`(2,=`0`````!(BP7RAR``
M2(M`"$C'0"``````2(L%WX<@`$B+0`A(BPW<AR``2(E(2$B#Q`A;7<-F#Q^$
M``````!52(GE05=!5D%44TB![!`$``!(BP6WAR``2(E%V,8%E(<@``%(BQU%
MC"``2(7;='^XX[I``.L,9@\?A```````2/_`B@B$R70%@/D]=?),BSM-A?]T
M6;GCND``*<A,8_!(@\,(9F9F+@\?A```````3(G_ON.Z0`!,B?+HW-___X7`
M=0=#@#PW/70.3(L[2(/#"$V%_W79ZQ9+C00^2/_`=`V`.#%U"$.`?#X"`'0%
MZ.SI__^_LKQ``+X!````N@L```#HY-W__TB%P`^$QP```(H->8L@`(3)#X2Y
M````2(M`$$R+<"@QVP\?@`````!,B?>)WC'2Z(#?__](A<!T74B+#5"+(`!,
MBWS9"$B+./9'#01U&C'VN@(```#HZN#__^L09F9F+@\?A```````2(M'$$R)
M_TB)QNB=X/__A<!U&XH%!XL@``^VR(/A`<'A`DC_PXU3`3G*?)3K!HH%[(H@
M``^VR(/A`8T,C?____\YRW4C-`&H`74=NP$```!,B??H%-W____##[8%OXH@
M`,'@`CG#?.B_M[Q``+X!````N@0```#H`-W__TB)PTB%VW0C2(M#$$B+.+ZY
MO$``Z/?<__](BT,02(LX]D<.0'0%Z/7>__^_+[M``+X!````N@0```#HP=S_
M_TF)QDV%]@^$%0$``$R+)7**(`!-A>1T:;BUND``ZPEF#Q]$``!(_\"*"(3)
M=`6`^3UU\DF+'"1(A=MT1;FUND``*<A,8_A)@\0(9F8N#Q^$``````!(B=^^
MM;I``$R)^N@,WO__A<!U"T*`/#L]#X2/````28L<)$F#Q`A(A=MUU$F+1A!,
MBR!(BP7>B2``3(LX2(VUT/O__[]BO4``NO\#``#HV=O__X7`?FI(B<)(P>(@
M2+D`````_____T@!T4C!^2"`O`W0^___`8/8`(7`?D-(8]A(C;W0^___OB\`
M``!(B=KH-]W__TB%P'0G2(VUT/O__TR)YTB)VNB`W?__ZQY)`=])BT803(L@
M2?_'#X1R____3(GG3(G^Z+#;___&!:6$(```2,<%@H0@``````!,BR5+B2``
M387D=&ZXK+I``.L29F9F9F9F+@\?A```````2/_`B@B$R70%@/D]=?))BQPD
M2(7;=$&YK+I``"G(3&/X28/$"&9F+@\?A```````2(G?OJRZ0`!,B?KHW-S_
M_X7`=0="@#P[/70:28L<)$F#Q`A(A=MUV$C'!;V((```````ZT=)`=])_\=,
MB3VNB"``=#A,B?^^P`$``.A[W/__A<!T"H/X$70%@_C_=4%(BP7Z@R``2#M%
MV'532('$$`0``%M!7$%>05]=PTB+/66((`#H*.W__TB)!6&((`!(A<!U,+^^
MO$``,,#H;-W__TB+#4&((`!(BS%(BQ4_B"``OP:]0`")P3#`Z$W=___HB-S_
M_TF+1A!(BSCV1PT$=0XQ]KH"````Z+_=___K!$B+1Q!(BS7^AR``2(G'Z(K:
M__]!B<=(BP7LAR``2(L828M&$$B+./9'#01U#C'VN@(```#HA-W__^L$2(M'
M$+_?O$``2(G>2(G"1(GY,,#HV=S__V9F9F8N#Q^$``````!52(GE05=!5D%5
M05132(/L*(E]U$B)=<A(B57`2(U]U$B-=<A(C57`Z,_<__]%,?^`/2F#(```
M=2#H/MK__TF)QTV%_P^$M`(``$R)_^CZVO__Q@5G@B```(`-@((@``.+1=2#
MP`5(8_AF2`]NQV8/8@5:&@``9@]<!6(:``!F#W#(3F8/6,AF#RX-81H```^'
M<P(``$C!YP/H_MO__TB)!0.'(`!(BWW(2(L/2(D(2,=`"$>]0`!(BPWJ@2``
M2(E($$C'0!A*O4``Q@7/AB```8M-U(/Y`GQ2N@$```!(NP`````$````2;@`
M`````0```.L:9F9F+@\?A```````3`'#2(L%GH8@`$B+?<A(BSS72(G>2,'^
M($B)//!(_\(YRGS<2(L%?88@`(/!`TACT4C'!-``````2(L-:(8@`$R)_[[P
M1D``13'`Z%S8__^%P'4(3(G_Z(#8__^)1;Q,B?_H==K__TR++5*&(`!-A>UT
M<[CSND``ZPEF#Q]$``!(_\"*"(3)=`6`^3UU\DF+70!(A=MT3[GSND``*<A,
M8^!-C74(9F8N#Q^$``````!(B=^^\[I``$R)XNCLV?__A<!U!T*`/",]=`Y)
MBQY)@\8(2(7;==GK#4D!W$F#_/\/A?D```!,BR7#A2``387D#X6.````387M
M=&VXK+I``.L19F9F9F8N#Q^$``````!(_\"*"(3)=`6`^3UU\DF+70!(A=MT
M0;FLND``*<A,8^!)@\4(9F8N#Q^$``````!(B=^^K+I``$R)XNA<V?__A<!U
M!T*`/",]=!I)BUT`28/%"$B%VW782,<%/84@``````#K:DD!W$G_Q$R))2Z%
M(`!T6TR)Y^B4XO__2(G#2(U#`>L.9F8N#Q^$``````!(_\"*2/^$R70'@/DO
M=-WK[^A:Y___A<!T)4&`/"0`=!Y(B=^^TKM``+H$````Z-G8__^%P'4(3(GG
MZ#'V__],B?_HI=;__^@`V/__BT6\2(/$*%M!7$%=05Y!7UW#OP$```#HM-G_
M_[^IND``OD#'8``PP.BSV?__#Q^``````%5(B>6_U%Y``+[L'D``NLA>0`#H
MM-G__[]-O4``OB`_0`"Z!;U``+D%O4``13'`7>GGU___9F8N#Q^$``````!5
M2(GE05=!5D%505132('L"`(``#'`9BX/'X0``````$B+3(<X2(G*2,'B"$B!
MX@``_P!(B<Y(@>;_````2,'F&$@)UDB)RTC!ZPA(B=I(@>(`_P``2`GR2(G.
M2,'N&$0/ML9)"=!(B<I(P>HX2,'I*$B!X0#_``!,B83%4/W__T@)T4B!Y@``
M_P!("<Z!XP```/]("?-(B9S%6/W__TB#P`*#^!`/C'7___\QP`\?`$B+C,60
M_?__2#.,Q;C]__](,XS%8/W__T@SC,50_?__2(G*2,'J'T@!R0G12(U0`4B)
MC,70_?__@_I`2(G0=<!,BP=(BW<(3(M_$$R)^4@A\4R+5QA(B?!(]]!,(=!(
M"<A,B<)(P>H;3(G!2,'A!4@)T4@#3R!(`<%(BX50_?__2(V,")EY@EI!B<E(
MB?!(P>@"2,'F'D@)QDR)P$C!Z`)-B<-)P>,>20G#3(G*2('B____!TC!X@5,
MB<A(P>@;2`G008GT3(GC3"'#3(G"2/?23"'Z2`G:3`'22`.56/W__TR-M!"9
M>8):18G:3"'11(G(]]!,(>!("<A$B?)(B=%(@>'___\'2,'A!4B)TTC!ZQM(
M"<M,`[U@_?__20''B='WT4PAT4R)R$C!Z`))@^$#2<'A'DD)P4Z-E#N9>8):
M18G43(G@2"7___\'2,'@!4R)XTC!ZQM("<--(<Y)"<Y(`[5H_?__3`'V2(G0
M2,'H`DB#X@-(P>(>2`G"3(VT,YEY@EI%B?=,B?A()?___P=(P>`%3(G^2,'N
M&T@)QDDATD2)X??13"')3`G13`.=</W__TD!RTR)X$C!Z`))@^0#2<'D'DD)
MQ$Z-E!Z9>8):1(G12(G(2"7___\'2,'@!4B)SDC![AM("<9-(>9$B?OWTT@A
MTTP)\TP#C7C]__])`=E,B?A(P>@"28/G`TG!YQY)"<=.C8P.F7F"6D6)RTR)
MV$@E____!TC!X`5,B=Y(P>X;2`G&32'ZB<OWTTPAXTP)TT@#E8#]__](`=I(
MB<A(P>@"2(/A`TC!X1Y("<%(C;06F7F"6D&)\DR)T$@E____!TC!X`5,B=-(
MP>L;2`G#22')1(G:]]),(?I,"<I,`Z6(_?__20'43(G82,'H`DF#XP-)P>,>
M20G#3HVT(YEY@EI%B?%,B<A()?___P=(P>`%3(G+2,'K&T@)PTPAWD2)TO?2
M2"'*2`GR3`.]D/W__TD!UTR)T$C!Z`))@^(#2<'B'DD)PDJ-G#N9>8):08G?
M3(GX2"7___\'2,'@!4R)_DC![AM("<9-(=9$B<CWT$PAV$P)\$@#C9C]__](
M`<%,B<A(P>@"28/A`TG!X1Y)"<%(C80.F7F"6HG&2(GR2('B____!TC!X@5(
MB?%(P>D;2`G13"'+1(GZ]]),(=)("=I,`YV@_?__20'33(GZ2,'J`DF#YP-)
MP><>20G73HV<&9EY@EI$B=M(B=I(@>+___\'2,'B!4B)V4C!Z1M("=%,(?B)
M\O?23"'*2`G"3`.5J/W__TD!TDB)\$C!Z`)(@^8#2,'F'D@)QDZ-E!&9>8):
M18G63(GP2"7___\'2,'@!4R)\4C!Z1M("<%)(?.)VO?23"'Z3`G:3`.-L/W_
M_TD!T4B)V$C!Z`)(@^,#2,'C'D@)PTZ-G`F9>8):18G93(G(2"7___\'2,'@
M!4R)R4C!Z1M("<%)(=I$B?+WTD@A\DP)TDP#O;C]__])`==,B?!(P>@"28/F
M`TG!YAY)"<9.C90YF7F"6D6)U$R)X$@E____!TC!X`5,B>%(P>D;2`G!32'S
M1(G(]]!((=A,"=A(`[7`_?__2`'&3(G(2,'H`DF#X0-)P>$>20G!2(V,,9EY
M@EI!B<],B?A()?___P=(P>`%3(G^2,'N&T@)QDTARD2)X/?03"'P3`G02`.=
MR/W__T@!PTR)X$C!Z`))@^0#2<'D'DD)Q$R-G!Z9>8):18G:3(G02"7___\'
M2,'@!4R)UDC![AM("<9,(>%$B?CWT$PAR$@)R$P#M=#]__])`<9,B?A(P>@"
M28/G`TG!YQY)"<=.C;0VF7F"6D2)\DB)T4B!X?___P=(P>$%2(G02,'H&T@)
MR$TA^T2)UO?63"'F3`G>3(G12,'I`DF#X@-)P>(>20G*3`.-V/W__TD!\4J-
MG`B9>8):B=A(B<%(P>D;2(G&2,'F!4@)SDTAUHG1]]%,(?E,"?%,`Z7@_?__
M20',2(G12,'I`DB#X@-(P>(>3HV<)IEY@EI("<I%B=E,B<Y(P>X;3(G)2,'A
M!4@)\4P#O>C]__^)QO?63"'63`.5\/W__T@ATT@)\TP!^TB)QDC![@)(@^`#
M2,'@'DR+M?C]__])`=9(C8P9F7F"6D@)\$@QPDPQVD&)RTR)SDC![@))@^$#
M2<'A'DD)\4R)RT@QPT@QRT@#A0#^__],B=Y(P>X;3(G92,'A!4@)\4P!TDB-
MC!&AZ]EN08G*3(G:2,'J`DF#XP-)P>,>20G33(G>3#'.2#'.3`.-"/[__TR)
MTDC!ZAM,B=%(P>$%2`G13`'S2(V<&:'KV6Y!B=],B=%(P>D"28/B`TG!XAY)
M"<I,B=%,,=E(,=E,`YT0_O__3(GZ2,'J&TR)^TC!XP5("=-(`<9(C9PSH>O9
M;HG83(G^2,'N`DF#YP-)P><>20GW3(G^3#'62#'>3`.5&/[__TB)PDC!ZAM(
MB<-(P>,%2`G33`')2(V<"Z'KV6Y!B=E(B<%(P>D"2(/@`TC!X!Y("<A(B<%,
M,?E(,=E,`[T@_O__3(G*2,'J&TR)RTC!XP5("=-,`=Y(C;0SH>O9;D&)\TR)
MRTC!ZP))@^$#2<'A'DD)V4R)RT@QPT@Q\T@#A2C^__],B=I(P>H;3(G>2,'F
M!4@)UDP!T4B-C`ZAZ]EN08G.3(G>2,'N`DF#XP-)P>,>20GS3(G>3#'.2#'.
M3`.-,/[__TR)\DC!ZAM,B?%(P>$%2`G13`'[2(V,&:'KV6Y!B<],B?-(P>L"
M28/F`TG!YAY)"=Y,B?-,,=M(,<M,`YTX_O__3(GZ2,'J&TR)^4C!X05("=%(
M`<9(C8PQH>O9;D&)RDR)^$C!Z`))@^<#2<'G'DD)QTR)^$PQ\$@QR$P#M4#^
M__],B=)(P>H;3(G12,'A!4@)T4P!RTB-C!FAZ]EN08G)3(G62,'N`DF#X@-)
MP>(>20GR3(G63#'^2#'.3`.]2/[__TR)RDC!ZAM,B<E(P>$%2`G13`'82(V$
M`:'KV6Y!B<-,B<E(P>D"28/A`TG!X1Y)"<E,B<E,,=%(,<%,`Y50_O__3(G:
M2,'J&TR)V$C!X`5("=!,`?9(C;0PH>O9;D&)]$R)V$C!Z`))@^,#2<'C'DD)
MPTR)V$PQR$@Q\$P#C5C^__],B>)(P>H;3(GF2,'F!4@)UDP!^4B-E`ZAZ]EN
MB=-,B>%(P>D"28/D`TG!Y!Y)"<Q,B>%,,=E(,=%,`YU@_O__2(G>2,'N&TB)
MVDC!X@5("?),`=!(C90"H>O9;D&)TDB)V$C!Z`)(@^,#2,'C'D@)PTB)V$PQ
MX$@QT$P#I6C^__],B=9(P>X;3(G22,'B!4@)\DP!R4R-C`JAZ]EN18G.3(G1
M2,'I`DF#X@-)P>(>38GW2<'O&TD)RDR)T4@QV4PQR4R)\DC!X@5,"?I,`=A(
MC80"H>O9;D&)P4R)RDC!ZAM,B<A(P>`%2`G03`'A3(GR2,'J`DF#Y@-(C80(
MH>O9;DG!YAY)"=:)P42)\$0QT$2)SC'&2(G*2,'J&TB)R$C!X`4)T`.=</[_
M_P'S3(G*2,'J`DF#X0-$`Y5X_O__2<'A'D2-K!BAZ]EN20G11(G(1#'P3`.U
M@/[__TB)RDC!Z@)(B<Y(@^8#2,'F'D@)UDF)]$TQS#'!3`.-B/[__TR)Z$C!
MZ!M,B>I(P>(%"<)$`=%$C9P*H>O9;DR)V$@E____!TR)VTB#XP-(P>`%33'L
M30'T38GN2<'N`DF#Y0-,B=I(P>H;2`G"2,'C'DV)VDG!Z@))"=I)P>4>3(N]
MD/[__TD!]TT)]4R)T$P)Z$J-E"*AZ]EN2"'03#'N3#'>3(G33"'K3`.MF/[_
M_T@)PTP!SD&)UDR)\$C!Z!M,B?)(@>+___\'2,'B!4@)PDR-I#*AZ]EN18GC
M3(G82"7___\'3`'[3(GV2,'N`DF#Y@-(P>`%2<'F'DR)VDC!ZAM("<)!N=R\
M&X])"?9,B?!,"=!(`=I,B?9,(=9,`Y6@_O__3"'@2`GP3(G>2,'N`DF#XP-)
MP>,>3`'H20GS3`'*B=-(B=E(@>'___\'2,'A!4B)WDC![AM("<Y,B=E,"?%(
M`<9,`<Y,B=A,(?!,`[6H_O__2"'12`G!2(G82,'H`DB#XP-(P>,>2`G#3`'1
M08GW3(GZ2('B____!TC!X@5,B?A(P>@;2`G02(N5L/[__TP!VD@!R$P!R$B)
MV4P)V4@A\4DAVTD)RTR)^4C!Z0))@^<#2<'G'DD)STT!\T&)QDR)]DB!YO__
M_P=(P>8%3(GQ2,'I&T@)\4R+E;C^__])`=I,`=E,`<E,B?Y("=Y((<9,(?M(
M"?-,B?!(P>@"28/F`TG!YAY)"<9(`=-!B<M,B=A()?___P=(P>`%3(G:2,'J
M&T@)PDB+A<#^__],`?A(`=I,`<I,B?9,"?Y((<Y-(?=)"?=,B=E(P>D"28/C
M`TG!XQY)"<M-`==!B=1,B>9(@>;___\'2,'F!4R)X4C!Z1M("?%,BY7(_O__
M30'R3`'Y3`')3(G>3`GV2"'632'>20GV3(GB2,'J`DF#Y`-)P>0>20G420'&
MB<A(B<9(@>;___\'2,'F!4B)PDC!ZAM("?),B[W0_O__30'?3`'R3`'*3(GF
M3`G>2"'.32'C20GS2(G!2,'I`DB#X`-(P>`>2`G(30'3B=-(B=Y(@>;___\'
M2,'F!4B)V4C!Z1M("?%,BY78_O__30'B3`'93`')2(G&3`GF2"'622'$20GT
M2(G:2,'J`DB#XP-(P>,>2`G330'\08G.3(GV2('F____!TC!Y@5,B?)(P>H;
M2`GR3(N=X/[__TD!PTP!XDP!RDB)WD@)QD@ASD@AV$@)\$R)\4C!Z0))@^8#
M2<'F'DD)SDP!T$&)U$R)YDB!YO___P=(P>8%3(GA2,'I&T@)\4R+E>C^__])
M`=I(`<%,`<E,B?!("=A((=!,(?-("<-,B>!(P>@"28/D`TG!Y!Y)"<1,`=N)
MR$B)QDB!YO___P=(P>8%2(G"2,'J&T@)\DR+G?#^__]-`?-(`=I,`<I,B>9,
M"?9((<Y-(>9)"?9(B<%(P>D"2(/@`TC!X!Y("<A-`=:)TTB)WDB!YO___P=(
MP>8%2(G92,'I&T@)\4R+E?C^__]-`>),`?%,`<E(B<9,">9((=9)(<1)"?1(
MB=I(P>H"2(/C`TC!XQY("=--`=Q!B<],B?Y(@>;___\'2,'F!4R)^DC!ZAM(
M"?),B[4`____20'&3`'B3`'*2(G>2`G&2"'.2"'82`GP3(GY2,'I`DF#YP-)
MP><>20G/3`'008G43(GF2('F____!TC!Y@5,B>%(P>D;2`GQ3(N="/___TD!
MVT@!P4P!R4R)^$@)V$@AT$PA^T@)PTR)X$C!Z`))@^0#2<'D'DD)Q$P!\T&)
MRDR)T$@E____!TC!X`5,B=)(P>H;2`G"2(N%$/___TP!^$@!VDP!RDR)YDP)
M_D@ASDTAYTD)]TR)T4C!Z0))@^(#2<'B'DD)RDT!WXG32(G>2('F____!TC!
MY@5(B=E(P>D;2`GQ3(N=&/___TT!XTP!^4R)UDP)YD@AUDTAU$D)]$B)VDC!
MZ@)(@^,#2,'C'DD!Q$@)TTP!R4&)SDR)\DB!XO___P=(P>(%3(GP2,'H&T@)
MT$B)VDP)TD@ARDF)WTTAUTP#E2#___],`>!,`<A,B?%(P>D"28/F`TG!YAY)
M"<Y,B?%("=E((<%)"=>)PDV)]$DAW$@#G2C___])"<Q-`=](B=%(@>'___\'
M2,'A!4B)T$C!Z!M("<A(B=%(P>D"2(/B`TC!XAY("<I(B=%,"?%,`?A,`<A(
M(<%-`=1!B<),B=9(P>X;3(G02,'@!4@)\$B)UDPA]DP#M3#___],`>!,`<A(
M"<Y(`=Y!B<1,B>-(P>L;3(GA2,'A!4@)V4R)TTC!ZP))@^(#2<'B'D@!\4R+
MG3C___])`=-)"=I,,=),`<E(,<),B>!(P>@"28/D`TG!Y!Y)"<1,B>!,,=!,
M`?),`Y5`____08G/3(G^2,'N&TR)^TC!XP5("?-!N=;!8LI(`=-,`<M(,<A,
M`=A!B=Y,B?)(P>H;3(GQ2,'A!4@)T4R)^DC!Z@))@^<#2<'G'D@!P4R+G4C_
M__]-`>-)"==-,?Q),=Q,`<E,B?!(P>@"28/F`TG!YAY)"<9,B?-,,?M,`[U0
M____2#'+30'4B<E(B<A(P>@;2(G.2,'F!4@)QDP!YDP!SD&)]$P!VTR)X$C!
MZ!M,B>)(P>(%2`G"2(G(2,'H`DB#X0-(P>$>2`G!2(G(3#'P3`.U6/___T@!
MVDP!RD@Q\$P!^$&)TTR)WDC![AM,B=M(P>,%2`GS3(GF2,'N`DF#Y`-)P>0>
M2`'#3(N58/___TD!RDD)]$PQX4@QT4P!RTR)V$C!Z`))@^,#2<'C'DD)PTR)
MV$PQX$P#I6C___](,=A,`?&)VTB)VDC!ZAM(B=Y(P>8%2`G62`'.3`'.08GV
M3`'03(GQ2,'I&TR)\DC!X@5("<I(B=E(P>D"2(/C`TC!XQY("<M(B=E,,=E,
M`YUP____2`'"3`'*2#'Q3`'A08G23(G02,'H&TR)UDC!Y@5("<9,B?!(P>@"
M28/F`TG!YAY(`<Y(BXUX____2`'920G&3#'S2#'33`'.3(G02,'H`DF#X@-)
MP>(>20G"38G733'W3`-U@$DQ]TP!VXGV2(GP2,'H&TB)\DC!X@5("<)(`=I,
M`<I!B=1)`<],B>!(P>@;3(GA2,'A!4@)P4B)\$C!Z`)(@^8#2,'F'D@)QDB)
M\$PQT$P#58A,`?E,`<E(,=!,`?!!B<Y,B?)(P>H;3(GS2,'C!4@)TTR)XDC!
MZ@))@^0#2<'D'D@!PTR+79!)`?-)"=1,,>9(,<Y,`<M,B?!(P>@"28/F`TG!
MYAY)"<9,B?!,,>!,`V682#'83`'6B=M(B=I(P>H;2(G92,'A!4@)T4@!\4P!
MR4&)STP!V$R)_DC![AM,B?I(P>(%2`GR2(G>2,'N`DB#XP-(P>,>2`GS2(G>
M3#'V2#'.3`'F2`'"3`'*08G33(G92,'I&TR)V$C!X`5("<A(`?!,B=Y(P>X"
M28/C`TR)^4C!Z0))@^<#2<'C'DG!YQY)"<],B?E(,=E(,=%)"?-,`<B)PDB)
MUDB#Y@-(P>8>28G22<'J`DD)\DR)WDPQ_D@QQDP#=:!(`UVH20'.2(G02,'H
M&TC!X@5("<),`?),`<J)TD@!\TB)T$C!Z!M(B=9(P>8%2`G&1(G81#'01(MU
MR$4!QD0#?;!,`UVX08G003'`2`'>3`'.2(G02,'H`DB#X@-(P>(>2`G"10'X
M08GW3(GX2,'H&TR)^TC!XP4)PTB)T4PQT4P#5<!"C9P#UL%BRD@Q\4R)_DC!
M[@))@^<#2<'G'D&)T$4!\$F)WDG![@))"?=,,?I(,=I,`=E)B=M)P>,>10GS
M2(G82,'H&TC!XP5$B=Y$,?Y("<-(`<M,`<LQWDP!THG;2(G82,'H&TB)V4B!
MX?___P=(P>$%2`G!2`'13`')B<E)B=E)P>D"1`'&2(G*2,'J&TC!XQY(B<A(
MP>`%1`G+"="-A##6P6+*2(D'`T\(2(E/"`-?$$B)7Q!$`U\83(E?&$0#?R!,
MB7\@2('$"`(``%M!7$%=05Y!7UW#D)"054B)Y5-02(L%LV,@`$B#^/]T'+L(
MPF``#Q^$``````#_T$B+`TB#P_A(@_C_=?%(@\0(6UW#D)!(@^P(Z&_$__](
M@\0(PP```````````````#!#```P10``````````````````,$,````````P
M10```````,!#+B]P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C
M875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T
M<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N
M9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@
M("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D
M:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F
M:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@
M("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@
M;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O
M9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@
M("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@
M("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@
M("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]
M('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T
M86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@
M('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@
M(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T
M:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T
M:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@
M86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL
M('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*
M("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@
M("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O
M7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@
M("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*
M("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@
M("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E
M<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N
M;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O
M6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA
M:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@
M("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F
M('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@
M9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@
M("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME
M>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[
M"@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS
M;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I
M;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@
M("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@
M("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@
M("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@
M("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@
M:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN
M;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^
M.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@
M("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@
M("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]
M"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN
M9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M"B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N
M86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@
M)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*
M("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!0
M05(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L
M;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H
M92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@
M("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@
M*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@
M("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G
M<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@
M("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@
M/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q
M=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E
M(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R
M;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@
M("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4[
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!0
M05(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER
M92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H
M:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O
M9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E
M;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@
M?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D
M<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@
M("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@
M?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H
M+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@
M("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S
M>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^
M(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@
M("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@
M:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@
M*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!
M3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@
M("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*
M<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@
M(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?
M=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@
M("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@
M("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@
M>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F
M:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L
M("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T
M=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]
M("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@
M("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@
M7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K
M('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@
M>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@
M("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]
M"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS
M=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F
M:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET
M7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@
M("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*
M?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C
M:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*`"]P<F]C+R5I+R5S`%!!
M4E]414U0`%!!4E]04D]'3D%-10!015),-4Q)0@!015),3$E"`%!%4DPU3U!4
M`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.
M`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?
M1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)
M0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42``O=&UP+P!414U0
M1$E2`%1-4`!54T52`%5315).04U%`'!A<BT`4UE35$5-`"4P,G@`)7,E<R5S
M)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE
M=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL
M960@*&5R<FYO/25I*0H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]C=7)P<F]C+V9I;&4`+BX`)7,O)7,`
M.@!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````````
M``````"RNT```````':]0````````````````````````````,2[0```````
MR;M```````````````````$;`SO$````%P```%AC___@````N&3__P@!``"(
M9?__*`$``*AE__](`0``>&;__V@!``"(9O__B`$``*AH__^P`0``V&K__]@!
M```(:___^`$``-AK__\8`@``&&___T`"``#X;___:`(``+AP__^0`@``V'#_
M_[`"``!8<O__V`(``(A^__\``P``^'[__R`#``!(@/__2`,``&B`__]H`P``
M.('__X@#``#HA?__L`,```B)___8`P``2(G___@#````````%``````````!
M>E(``7@0`1L,!PB0`0``)````!P```!P8O__5@$```!!#A"&`D,-!DJ#!XP&
MC06.!(\#`````!P```!$````J&/__U4`````00X0A@)##09"@P,`````'```
M`&0```!89/__&0````!!#A"&`D,-!@`````````<````A````%AD___#````
M`$$.$(8"0PT&3(,%C@2/`QP```"D````"&7__PH`````00X0A@)##08`````
M````)````,0```#X9/__&@(```!!#A"&`D,-!E"#!XP&C06.!(\#`````"0`
M``#L````\&;__R\"````00X0A@)##09-@P>,!HT%C@2/`P`````<````%`$`
M`/AH__\I`````$$.$(8"0PT&`````````!P````T`0``"&G__\D`````00X0
MA@)##09#@P2.`P``)````%0!``"X:?__0`,```!!#A"&`D,-!DV#!XP&C06.
M!(\#`````"0```!\`0``T&S__]\`````00X0A@)##09*@P>,!HT%C@2/`P``
M```D````I`$``(AM__^Z`````$$.$(8"0PT&1X,&C`6.!(\#````````'```
M`,P!```@;O__'@````!!#A"&`D,-!@`````````D````[`$``"!N__]T`0``
M`$$.$(8"0PT&38,'C`:-!8X$CP,`````)````!0"``!X;___+0P```!!#A"&
M`D,-!E"#!XP&C06.!(\#`````!P````\`@``@'O__VD`````00X0A@)##09#
M@P2.`P``)````%P"``#0>___1P$```!!#A"&`D,-!DV#!XP&C06.!(\#````
M`!P```"$`@``^'S__QL`````00X0A@)##08`````````'````*0"``#X?/__
MQP````!!#A"&`D,-!D*#`P`````D````Q`(``*A]__^C!````$$.$(8"0PT&
M3H,&C`6.!(\#````````)````.P"```P@O__&0,```!!#A"&`D,-!DV#!XP&
MC06.!(\#`````!P````4`P``*(7__S4`````00X0A@)##08`````````)```
M`#0#``!(A?__'1<```!!#A"&`D,-!E"#!XP&C06.!(\#````````````````
M__________\``````````/__________``````````````````````$`````
M`````0`````````!``````````<"`````````0`````````1`@````````$`
M````````'P(````````!`````````"P"`````````0````````!0`@``````
M``\`````````AP,````````=`````````(<#````````#``````````H'4``
M``````T`````````B%Y````````$`````````$@"0```````]?[_;P````!H
M!4````````4`````````.!!````````&`````````,`&0```````"@``````
M``"K!`````````L`````````&``````````5`````````````````````P``
M``````!(Q&````````(`````````Z`4````````4``````````<`````````
M%P````````!`%T````````<`````````\!5````````(`````````%`!````
M````"0`````````8`````````/[__V\`````L!5```````#___]O``````(`
M````````\/__;P````#D%$``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#C"8```````````````````
M`````````%(=0```````8AU```````!R'4```````((=0```````DAU`````
M``"B'4```````+(=0```````PAU```````#2'4```````.(=0```````\AU`
M```````"'D```````!(>0```````(AY````````R'D```````$(>0```````
M4AY```````!B'D```````'(>0```````@AY```````"2'D```````*(>0```
M````LAY```````#"'D```````-(>0```````XAY```````#R'D````````(?
M0```````$A]````````B'T```````#(?0```````0A]```````!2'T``````
M`&(?0```````<A]```````""'T```````)(?0```````HA]```````"R'T``
M`````,(?0```````TA]```````#B'T```````/(?0````````B!````````2
M($```````"(@0```````,B!```````!"($```````%(@0```````8B!`````
M``!R($```````((@0```````DB!```````"B($```````+(@0```````PB!`
M``````#2($```````.(@0```````\B!````````"(4```````!(A0```````
M(B%````````R(4````````6]0``````````````````HPF``````````````
M````\%Y```````#_____)$9R965"4T0Z(&AE860O;&EB+V-S=2]A;60V-"]C
M<G0Q+F,@,C0U,3,S(#(P,3,M,#$M,#<@,3<Z-3@Z,C=:(&MI8B`D`"1&<F5E
M0E-$.B!H96%D+VQI8B]C<W4O8V]M;6]N+V-R=&)R86YD+F,@,C,R.#,R(#(P
M,3(M,#,M,3$@,C`Z,#0Z,#E:(&MI8B`D`"1&<F5E0E-$.B!H96%D+VQI8B]C
M<W4O8V]M;6]N+VEG;F]R95]I;FET+F,@,C0U,3,S(#(P,3,M,#$M,#<@,3<Z
M-3@Z,C=:(&MI8B`D`"1&<F5E0E-$.B!H96%D+VQI8B]C<W4O86UD-C0O8W)T
M:2Y3(#(Q-S$P-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)``D1G)E94)3
M1#H@:&5A9"]L:6(O8W-U+V%M9#8T+V-R=&XN4R`R,3<Q,#4@,C`Q,2TP,2TP
M-R`Q-CHP-SHU,5H@:VEB("0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+G1A
M9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD
M=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M```````````````````````````````````````+`````0````(`````````
M``)``````````@```````!4````````````````````!````````````````
M````$P````<````"`````````!@"0```````&`(````````P````````````
M````````!````````````````````"$````%`````@````````!(`D``````
M`$@"````````(`,````````%``````````@`````````!``````````=````
M]O__;P(`````````:`5```````!H!0```````%@!````````!0`````````(
M````````````````````)P````L````"`````````,`&0```````P`8`````
M``!X"0````````8````!````"``````````8`````````"\````#`````@``
M```````X$$```````#@0````````JP0```````````````````$`````````
M```````````W````____;P(`````````Y!1```````#D%````````,H`````
M````!0`````````"``````````(`````````1````/[__V\"`````````+`5
M0```````L!4```````!```````````8````"````"```````````````````
M`%,````$`````@````````#P%4```````/`5````````4`$````````%````
M``````@`````````&`````````!=````!`````(`````````0!=```````!`
M%P```````.@%````````!0````P````(`````````!@`````````9P````$`
M```&`````````"@=0```````*!T````````3````````````````````!```
M`````````````````&(````!````!@`````````\'4```````#P=````````
M``0```````````````````0`````````$`````````!M`````0````8`````
M````0"%```````!`(0```````$@]```````````````````0````````````
M````````<P````$````&`````````(A>0```````B%X````````.````````
M````````````!````````````````````'D````!`````@````````"@7D``
M`````*!>````````2%\``````````````````!````````````````````"!
M`````0````(`````````Z+U```````#HO0```````,0`````````````````
M```$````````````````````CP````$````"`````````+"^0```````L+X`
M``````!<`P``````````````````"````````````````````)D````!````
M`P`````````0PF```````!#"````````$`````````````````````@`````
M``````````````"@`````0````,`````````(,)@```````@P@```````!``
M```````````````````(````````````````````IP````$````#````````
M`##"8```````,,(````````(````````````````````"```````````````
M`````*P````&`````P`````````XPF```````#C"````````$`(````````&
M``````````@`````````$`````````"U`````0````,`````````2,1@````
M``!(Q````````!`"```````````````````(``````````@`````````O@``
M``$````#`````````%C&8```````6,8````````L````````````````````
M"````````````````````,0````(`````P````````"0QF```````(3&````
M````"`4``````````````````!````````````````````#)`````0```#``
M``````````````````"$Q@```````&L!```````````````````!````````
M``$``````````0````,`````````````````````````[\<```````#2````
<`````````````````0``````````````````````
